@@ -8,10 +8,12 @@ import colorama
 import unittest
 import time
 import textwrap
+
 from unitgrade.runners import UTextResult
 from unitgrade.utils import gprint, Capturing2, Capturing
 colorama.init(autoreset=True)  # auto resets your settings after every output
 import numpy
+
 numpy.seterr(all='raise')
 
 def setup_dir_by_class(C, base_dir):
@@ -45,21 +47,15 @@ class Report:
 
     def _import_base_relative(self):
         if hasattr(self.pack_imports[0], '__path__'):
-            # im = self.pack_imports[0]
-            # print("im!!!!")
-            # print(im.__path__)
-            # if isinstance(im, list):
-            #     print("im is", im)
-            # __path__ was originally not a list; but now it seems like it behaves like a list. Add check if problem persists and treat it as either list or string.
-            # root_dir = self.pack_imports[0].__path__[0]._path[0]
             root_dir = self.pack_imports[0].__path__[0]
-
         else:
             root_dir = self.pack_imports[0].__file__
 
         root_dir = os.path.dirname(root_dir)
         relative_path = os.path.relpath(self._file(), root_dir)
         modules = os.path.normpath(relative_path[:-3]).split(os.sep)
+        relative_path = relative_path.replace("\\", "/")
+
         return root_dir, relative_path, modules
 
     def __init__(self, strict=False, payload=None):
@@ -411,7 +407,7 @@ class UTestCase(unittest.TestCase):
                 # np.testing.assert_almost_equal
                 # import numpy as np
                 print(f"|first - second|_max = {max_diff} > {tol} ")
-                np.testing.assert_almost_equal(first, second, msg=f'Not equal within tolerance {tol}')
+                np.testing.assert_almost_equal(first, second)
                 # If the above fail, make sure to throw an error:
                 self.assertFalse(max_diff >= tol, msg=f'Input arrays are not equal within tolerance {tol}')
                 # self.assertEqual(first, second, msg=f'Not equal within tolerance {tol}')
@@ -433,7 +429,7 @@ class UTestCase(unittest.TestCase):
                 msg = "" if msg is None else msg
                 print(f"|first - second|_2 = {max_diff} > {tol} ")
                 # Deletage to numpy. Let numpy make nicer messages.
-                np.testing.assert_almost_equal(first, second, msg=f'Not equal within tolerance {tol}')
+                np.testing.assert_almost_equal(first, second) # This function does not take a msg parameter.
                 # Make sure to throw an error no matter what.
                 self.assertFalse(max_diff >= tol, msg=f'Input arrays are not equal within tolerance {tol}')
                 # self.assertEqual(first, second, msg=msg + f"Not equal within tolerance {tol}")
@@ -496,6 +492,7 @@ class UTestCase(unittest.TestCase):
                             gprint(f">      - {l}")
 
                 er = er[0]
+
                 doc = er._testMethodDoc
                 # print("doc", doc)
                 if doc is not None:
